__title__ = 'alpha-vantage-py'
__description__ = 'Alpha Vantage Python package.'
__url__ = 'https://github.com/wstolk/vantage-py'
__version__ = '0.0.3'
__build__ = 0x022501
__author__ = 'Wouter Stolk'
__author_email__ = 'stolk.wouter@gmail.com'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2021 Wouter Stolk'
__cake__ = u'\u2728 \U0001f370 \u2728'